# ============================================================================
# Zhu3D Version 4.2.4. (c) 2012 Heinz van Saanen
# ============================================================================


# ============================================================================
# PLAIN USAGE:
# ============================================================================
# "Normal" users will need just a simple qmake. All paths for the default
# directories are automatically relative to the application path then.
#
# Using Intel compiler ICC instead of GCC:
#
# 1) Enable ICC-compilation switch in next paragraph
# 2) Use "qmake -spec linux-icc" then instead of "qmake" solely


# ============================================================================
# BASIC COMPILATION SWITCHES: (Uncomment to enable them)
# ============================================================================
# 1) Enable debugging
# 2) Use SSE3 for OpenGL list generation
# 3) Use Intel ICC. Produce makefile with "qmake -spec linux-icc" then
# ============================================================================
# ZHUDEBUG = yes
# USE_SSE3 = yes
# USE_ICPC = yes


# ============================================================================
# PACKAGERS/TAILORING:
# ============================================================================
# As packager or for tailoring you easily can redefine the locations of the
# default directories or default Gui. Open and edit the file zhu3d.pri for
# this. More information is included there.


# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
# From here onwards, quite likely all entries/settings are interesting for
# hardcore users and speed-optimising only.
# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++


# ============================================================================
# General configure stuff. Do not change this for no really good reasons.
# ============================================================================
TEMPLATE  = app
CONFIG   += release
TARGET    = zhu3d
QT       += opengl


# ============================================================================
# Optimisation switches. For both GCC/ICC compilers -O3 is default.
# ============================================================================

# Handle SSE3 stuff for both GCC/ICC
!isEmpty(USE_SSE3) { QMAKE_CFLAGS_RELEASE   += -msse3 }
!isEmpty(USE_SSE3) { QMAKE_CXXFLAGS_RELEASE += -msse3 }

# Handle ICC specific stuff. Note: ICC/*nix needs -use-msasm mandatory
!isEmpty(USE_ICPC) { QMAKE_CFLAGS_RELEASE   -= -msse3 }
!isEmpty(USE_ICPC) { QMAKE_CXXFLAGS_RELEASE -= -msse3 }
!isEmpty(USE_ICPC) { QMAKE_CFLAGS_RELEASE   += -use-msasm }
!isEmpty(USE_ICPC) { QMAKE_CXXFLAGS_RELEASE += -use-msasm }

# Enable -O3 instead of -O2 as default. For ICC -fast may be worth a try
QMAKE_CFLAGS_RELEASE   -= -O2
QMAKE_CFLAGS_RELEASE   += -O3
QMAKE_CXXFLAGS_RELEASE -= -O2
QMAKE_CXXFLAGS_RELEASE += -O3

# Enable CPU-optimisations. For GCC and Core2 this is a little boost e.g:
# QMAKE_CFLAGS_RELEASE   += -march=core2
# QMAKE_CXXFLAGS_RELEASE += -march=core2

# Try to strip executable as default
QMAKE_CFLAGS_RELEASE   += -s
QMAKE_CXXFLAGS_RELEASE += -s


# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
# From here onwards, all entries and settings are interesting for hardcore
# developers or packagers only. But even those may happily ignore the rest:-)
# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++


# ============================================================================
# Include the definition file to set default paths. Made on *nix-systems only
# ============================================================================
!win32 { include("zhu3d.pri") }


# ============================================================================
# Header files
# ============================================================================
HEADERS = ./src/mainwindow.h \
          ./src/glwidget.h \
          ./src/gldraw.h \
          ./src/solver.h \
          ./src/warp/fparser.h \
          ./src/warp/fpconfig.h \
          ./src/warp/pwarp/pfparser.h \
          ./src/warp/pwarp/pfpconfig.h \
          ./src/pinterface.h \
          ./src/ppinterface.h \
          ./src/piso.h \
          ./src/ligedit.h \
          ./src/matedit.h \
          ./src/entedit.h \
          ./src/aniedit.h \
          ./src/moredit.h \
          ./src/picedit.h \
          ./src/fntedit.h \
          ./src/demedit.h \
          ./src/funedit.h \
          ./src/speedit.h \
          ./src/diredit.h \
          ./src/usredit.h \
          ./src/legedit.h \
          ./src/property.h \
          ./src/version.h \
          ./src/timers.h \
          ./src/tsc.h \
          ./src/qadran.h \
          ./src/sysinfo.h \
          ./src/cpuinfo.h \
          ./src/paths.h \
          ./src/iso.h \
          ./src/fileio.h

!isEmpty(ZHUDEBUG)  { HEADERS += ./src/error.h }


# ============================================================================
# Source files
# ============================================================================
SOURCES = ./src/main.cpp \
          ./src/mainwindow.cpp \
          ./src/glwidget.cpp \
          ./src/gldraw.cpp \
          ./src/warp/fparser.cpp \
          ./src/warp/fpoptimizer.cpp \
          ./src/warp/pwarp/pfparser.cpp \
          ./src/pinterface.cpp \
          ./src/ppinterface.cpp \
          ./src/piso.cpp \
          ./src/ligedit.cpp \
          ./src/matedit.cpp \
          ./src/entedit.cpp \
          ./src/aniedit.cpp \
          ./src/moredit.cpp \
          ./src/picedit.cpp \
          ./src/fntedit.cpp \
          ./src/demedit.cpp \
          ./src/funedit.cpp \
          ./src/speedit.cpp \
          ./src/diredit.cpp \
          ./src/usredit.cpp \
          ./src/legedit.cpp \
          ./src/property.cpp \
          ./src/solver.cpp \
          ./src/sysinfo.cpp \
          ./src/iso.cpp \
          ./src/fileio.cpp

!isEmpty(ZHUDEBUG)  { SOURCES += ./src/error.cpp }


# ============================================================================
# User interface files
# ============================================================================
FORMS =   ./src/ui/mainwindow.ui \
          ./src/ui/ligedit.ui \
          ./src/ui/matedit.ui \
          ./src/ui/entedit.ui \
          ./src/ui/aniedit.ui \
          ./src/ui/moredit.ui \
          ./src/ui/picedit.ui \
          ./src/ui/funedit.ui \
          ./src/ui/speedit.ui \
          ./src/ui/diredit.ui \
          ./src/ui/legedit.ui

!isEmpty(ZHUDEBUG)  { FORMS += ./src/ui/error.ui }


# ============================================================================
# Translation files
# ============================================================================
!isEmpty(SYSDIR) {
    TRANSLATIONS = $$SYSDIR/languages/zhu3d_es.ts \
                   $$SYSDIR/languages/zhu3d_de.ts \
                   $$SYSDIR/languages/zhu3d_zh.ts \
                   $$SYSDIR/languages/zhu3d_fr.ts \
                   $$SYSDIR/languages/zhu3d_cs.ts }
else {
    TRANSLATIONS = ./system/languages/zhu3d_es.ts \
                   ./system/languages/zhu3d_de.ts \
                   ./system/languages/zhu3d_zh.ts \
                   ./system/languages/zhu3d_fr.ts \
                   ./system/languages/zhu3d_cs.ts }


# ============================================================================
# Determine *nix respectively Windows-resource files
# ============================================================================
RESOURCES = ./src/zhu3d.qrc
RC_FILE   = ./src/winicon.rc


# ============================================================================
# Consider extra Windows-libraries
# ============================================================================
win32 { LIBS += -lwinmm }


# ============================================================================
# The last section sets specific paths and therefore is interesting only for
# debugging or when you edited zhu3d.pri for packaging/tailoring purposes.
# ============================================================================

# Consider pri-file settings for *nix-systems. Handled automatically
!isEmpty(SYSDIR)  { QMAKE_CXXFLAGS_RELEASE+=-DSYSDIR="\\\"$${SYSDIR}\\\"" }
!isEmpty(DOCDIR)  { QMAKE_CXXFLAGS_RELEASE+=-DDOCDIR="\\\"$${DOCDIR}\\\"" }
!isEmpty(WORKDIR) { QMAKE_CXXFLAGS_RELEASE+=-DWORKDIR="\\\"$${WORKDIR}\\\"" }
!isEmpty(TEXDIR)  { QMAKE_CXXFLAGS_RELEASE+=-DTEXDIR="\\\"$${TEXDIR}\\\"" }
!isEmpty(DEFGUI)  { QMAKE_CXXFLAGS_RELEASE+=-DDEFGUI="\\\"$${DEFGUI}\\\"" }

# Consider Debug/SSE3 switches. Handled automatically
!isEmpty(ZHUDEBUG) { QMAKE_CXXFLAGS_RELEASE+=-DZHUDEBUG="yes" }
!isEmpty(USE_SSE3) { QMAKE_CXXFLAGS_RELEASE+=-DUSE_SSE3="yes" }
